@@ -38,11 +38,18 @@ def env_var(var: str, default: Optional[str] = None) -> str:
         raise Exception(msg)
 
 
+def not_match(result, pattern) -> str:
+    if pattern in result:
+        raise Exception(f"Found {pattern} in {result}")
+    return "true"
+
+
 def setup_jinja() -> Environment:
     env = Environment()
     env.globals['any'] = any
     env.globals['is_datetime'] = is_datetime
     env.globals['env_var'] = env_var
+    env.globals['not_match'] = not_match
     return env
 
 
